import { FunctionQueryMatcher, QueryMatcher, RawQuery } from '../types/mock-client';
import { queryMethods } from './constants';
import { MockConnection } from './MockConnection';
export declare type TrackerConfig = Record<string, unknown>;
export declare type TransactionState = {
    id: number;
    parent?: number;
    state: 'ongoing' | 'committed' | 'rolled back';
    queries: RawQuery[];
};
interface Handler<T = any> {
    data: T | ((rawQuery: RawQuery) => T);
    match: FunctionQueryMatcher;
    errorMessage?: string;
    once?: true;
}
declare type ResponseTypes = {
    response: <T = any>(data: Handler<T>['data']) => Tracker;
    responseOnce: <T = any>(data: Handler<T>['data']) => Tracker;
    simulateError: (data: Handler<any>['data']) => Tracker;
    simulateErrorOnce: (data: Handler<any>['data']) => Tracker;
};
declare type QueryMethodType = typeof queryMethods[number];
declare type History = Record<QueryMethodType, RawQuery[]> & {
    transactions: TransactionState[];
};
export declare class Tracker {
    readonly history: History;
    readonly on: Record<"select" | "insert" | "update" | "delete" | "any", (rawQueryMatcher: QueryMatcher) => ResponseTypes>;
    private readonly config;
    private responses;
    constructor(trackerConfig: TrackerConfig);
    _handle(connection: MockConnection, rawQuery: RawQuery): Promise<any>;
    reset(): void;
    resetHandlers(): void;
    resetHistory(): void;
    private receiveTransactionCommand;
    private prepareMatcher;
    private prepareStatement;
    private static applyPostOp;
}
export {};
